@@ -8,6 +8,7 @@ class Articles:
     _url_get_atributs = '/articles/{article_id}/articles_atributs'
     _url_get_articles_lots = '/articles_lots?article_atribut_id={article_atribut_id}'
     _url_get_article_lot = '/articles_lots?lot={lot}&article_atribut_id={article_atribut_id}'
+    _url_get_article_lot_ex = '/articles_lots/ex?lot={lot}&article_atribut_id={article_atribut_id}'
     _url_get_article_lot_id = '/articles_lots/{id}'
     _url_get_article_estoc_magatzem = '/articles_estocs/{article_atribut_id}?magatzem_id={magatzem_id}'
     _url_post_article_lot = '/articles_lots'
@@ -48,9 +49,8 @@ class Articles:
         req = self._con.get(url=tmp_url)
         return req.json()
 
-    def get_article_lot(self, p_article_atribut_id: int, p_lot: str, p_magatzem_id: int = None, p_palet_complert: bool = None):
-        tmp_url = Articles._url_get_article_lot.format(article_atribut_id=p_article_atribut_id, lot=p_lot)
-        req = self._con.get(url=tmp_url)
+    def get_article_lot_estoc(self, p_article_atribut_id: int, p_lot: str, p_magatzem_id: int = None, p_palet_complert: bool = None):
+        tmp_url = Articles._url_get_article_lot_ex.format(article_atribut_id=p_article_atribut_id, lot=p_lot)
         if p_palet_complert is not None:
             if p_palet_complert is True:
                 tmp_url += "&palet_complert=S"
@@ -58,6 +58,19 @@ class Articles:
                 tmp_url += "&palet_complert=N"
         if p_magatzem_id is not None:
             tmp_url += "&magatzem_id="+str(p_magatzem_id)
+
+        req = self._con.get(url=tmp_url)
+
+        result = None
+        if req is not None:
+            llista = req.json()
+            if len(llista) == 1:
+                result = llista[0]
+        return result
+
+    def get_article_lot(self, p_article_atribut_id: int, p_lot: str):
+        tmp_url = Articles._url_get_article_lot.format(article_atribut_id=p_article_atribut_id, lot=p_lot)
+        req = self._con.get(url=tmp_url)
         result = None
         if req is not None:
             llista = req.json()
