@@ -2,12 +2,18 @@ sync_productes = """
 select 
     p.EMPRESA_ID, p.ID, p.ARTICLE, p.CODI_ARTICLE, pa.ID ATRIBUT_ID, 
     p.DATA_BAIXA, pm.PES PES_NET, pm.PES + pm.TARA PES_BRUT, pm.AMPLADA, pm.LLARGADA,
-    pm.ALTURA, pe.EAN13_ARTICLE, 1, pe.EAN13_CAIXA, pp.UNITATS_SUP, pl.CONTROL_LOTS_VENDA
+    pm.ALTURA, pe.EAN13_ARTICLE, 1, pe.EAN13_CAIXA, pp.UNITATS_SUP, pl.CONTROL_LOTS_VENDA,
+    alf.tip_unitat_logistica_id, alf.unitat_logistica_format_id, alf.unitats_pal
 from ARTICLES p
 join ARTICLES_ATRIBUTS pa on p.ID = pa.ARTICLE_ID
 join ARTICLES_MIDES pm on p.ID = pm.ARTICLE_ID
 join ARTICLES_EANS pe on pa.ID = pe.ARTICLE_ATRIBUT_ID
 join ARTICLES_PARAMETRES pp on p.ID = pp.ARTICLE_ID
+left join ( select article_id,tip_unitat_logistica_id, max(unitat_logistica_format_id) unitat_logistica_format_id,max(unitats_pal) unitats_pal
+               from articles_logistica_formats alf
+               join tip_unitats_logistiques tu on tu.id = alf.tip_unitat_logistica_id
+              where tu.palet = 'S'
+               group by article_id,tip_unitat_logistica_id ) alf on alf.article_id = p.id
 left join SELECT_ARTICLES_C_ESTOCS(p.ID, CURRENT_DATE) pl on p.ID = pl.ARTICLE_ID
 join (select ARTICLE_ATRIBUT_ID, SUM(QUANTITAT_TOTAL) STOCK 
        FROM  ARTICLES_ESTOCS 
